@@ -15,7 +15,7 @@
 -export([start/4]).
 
 -define(NEED_ESDL, 1).
--include("wings.hrl").
+-include_lib("wings/src/wings.hrl").
 -include("auv.hrl").
 
 -import(lists, [sort/1,map/2,member/2,foldl/3,reverse/1]).
@@ -36,11 +36,6 @@
 start(Op, #we{id=Id}=We0, OrigWe, St0) ->
     Modes = [vertex,edge,face],
     wings:mode_restriction(Modes),
-    This = wings_wm:this(),
-    Allowed = [view,select],
-    Menu  = [Item || {_,Name,_}=Item <- get(wings_menu_template),
-		     member(Name, Allowed)],
-    wings_wm:menubar(This, Menu),
     wings_pref:set_value(scene_lights, false), %% ugly hack 
     
     St1 = seg_create_materials(St0),
@@ -61,7 +56,13 @@ start(Op, #we{id=Id}=We0, OrigWe, St0) ->
 
     St = St1#st{sel=[],selmode=face,shapes=gb_trees:from_orddict([{Id,We}])},
     Ss = seg_init_message(#seg{selmodes=Modes,st=St,orig_st=St0,we=OrigWe,fs=Fs}),
-    
+
+    %% Set camera on object/faces
+    RemoveOthers = fun(Sel, #we{id=SelId}) when SelId =:= Id -> Sel;
+                      (_, _) -> gb_sets:empty()
+                   end,
+    wings_view:command(frame, wings_sel:update_sel(RemoveOthers, St0)),
+
     %% Don't push here - instead replace the default crash handler
     %% which is the only item on the stack.
     get_seg_event(Ss).
@@ -140,12 +141,19 @@ seg_event_3(Ev, #seg{st=#st{selmode=Mode}}=Ss) ->
 -ifndef(DEBUG).
 seg_debug(Tail) -> Tail.
 mappers() ->
-    [{?__(1,"Unfolding"),lsqcm},				  
-     {?__(2,"Projection Normal"),project},
-     {?__(3,"Projection Camera"),camera},
-     {?__(4,"Sphere Map"),sphere}
-    ,{?__(5,"Cylindrical Map"),cyl}
-    ].
+    First = case erlang:system_info(wordsize) of
+                4 ->
+                    [{?__(1,"Unfolding"),lsqcm}];
+                8 ->
+                    [{?__(1,"Unfolding"),lsqcm},
+                     {?__(6,"Unfolding (slower)"),slim}]
+            end,
+    First ++
+        [{?__(2,"Projection Normal"),project},
+         {?__(3,"Projection Camera"),camera},
+         {?__(4,"Sphere Map"),sphere},
+         {?__(5,"Cylindrical Map"),cyl}
+        ].
 -else.
 seg_debug(Tail) ->
     [separator,
@@ -155,9 +163,11 @@ seg_debug(Tail) ->
 	{?__(3,"Select seeds"),select_seeds},
         {?__(4,"Select Pinned vertices"), select_pinned}]}}|Tail].
 mappers() ->
-    [{?__(1,"Unfolding"),lsqcm}, 
+    [{?__(1,"Unfolding (lscm alg)"),lsqcm},
      {?__(2,"Two pass Unfolding"),lsqcm2},
-     {?__(3,"Projection"),project}].
+     {?__(6,"Unfolding (slim alg)"),slim},
+     {"Harmonic", harmonic},
+     {?__(2,"Projection Normal"),project}].
 -endif.
 
 seg_mode_menu(vertex, _, Tail) -> Tail;
@@ -386,26 +396,22 @@ seg_map_charts_1([We0|Cs], Type, Id, N, Acc,Failed,Ss) ->
 seg_map_charts_1([],_, _, _,Charts0,Failed,
 		 Ss = #seg{orig_st=GeomSt0,fs=Fs,st=St0,we=#we{id=Id}}) ->
     wings_pb:done(),
-    %% Empty display list structure.
-    wings_dl:update(fun(eol, _) -> eol;
-		       (_, _) -> deleted
-		    end, []),
-    if Charts0 == [] -> 
+    if Charts0 == [] ->
 	    wings_u:message(Ss#seg.err),
 	    get_seg_event(seg_init_message(Ss));
        true ->
 	    Charts = reverse(Charts0),
 	    We = gb_trees:get(Id, GeomSt0#st.shapes),
 	    GeomSt = wpc_autouv:init_show_maps(Charts, Fs, We, GeomSt0),
-	    case Failed of 
-		[] -> 
+	    case Failed of
+		[] ->
 		    cleanup_before_exit(),
 		    delete;
 		_ ->
 		    wings_u:message(Ss#seg.err),
 		    #st{shapes=Shs} = St0,
 		    [We0] = gb_trees:values(Shs),
-		    Keep = foldl(fun(#we{fs=Ftab},Acc) -> 
+		    Keep = foldl(fun(#we{fs=Ftab},Acc) ->
 					 New = gb_sets:from_ordset(gb_trees:keys(Ftab)),
 					 gb_sets:union(New,Acc)
 				 end, gb_sets:empty(), Failed),
