@@ -412,13 +412,7 @@ command_menu(body, X, Y) ->
 	       {?__(19,"Left"), left, ?__(20,"Move to left border")},
 	       {?__(21,"Right"), right, ?__(22,"Move to right border")}
 	      ]}, ?__(23,"Move charts to position")},
-	    {?__(93,"Align"),
-	     {align,
-	      [{?__(15,"Bottom"), bottom, ?__(95,"Align to bottom")},
-	       {?__(17,"Top"), top, ?__(96,"Align to top")},
-	       {?__(19,"Left"), left, ?__(97,"Align to left")},
-	       {?__(21,"Right"), right, ?__(98,"Align to right")}
-	      ]}, ?__(94,"Align charts relative each other")},
+        align_menu(),
 	    {?__(24,"Flip"),{flip,
                              [{?__(25,"Horizontal"),horizontal,?__(26,"Flip selection horizontally")},
                               {?__(27,"Vertical"),vertical,?__(28,"Flip selection vertically")}]},
@@ -459,7 +453,9 @@ command_menu(edge, X, Y) ->
 	    {?__(643,"Distribute"),
 	     {equal,
 	      [{?__(25,"Horizontal"),horizontal,?__(644,"Distribute horizontally")},
-	       {?__(27,"Vertical"),vertical,?__(645,"Distribute vertically")}]},
+	       {?__(27,"Vertical"),vertical,?__(645,"Distribute vertically")},
+           separator,
+           {?__(647,"Proportional"),proportional,?__(648,"Proportionally distributes the vertices on loop to match the proportions on the object")}]},
 	     ?__(646,"Distribute vertices evenly")},
 	    separator,
 	    {?__(66,"Stitch"), stitch, ?__(67,"Stitch edges/charts")},
@@ -470,11 +466,11 @@ command_menu(vertex, X, Y) ->
     Scale = scale_directions(true),
     Move = move_directions(true),
     Align =
-	[{?__(70,"Free"),free,?__(71,"Rotate selection freely"), [magnet]},
-	 {?__(72,"Chart to X"), align_x,
-	  ?__(73,"Rotate chart to align (imaginary) edge joining selected verts to X-axis")},
-	 {?__(74,"Chart to Y"), align_y,
-	  ?__(75,"Rotate chart to align (imaginary) edge joining selected verts to Y-axis")}],
+        [{?__(70,"Free"),free,?__(71,"Rotate selection freely"), [magnet]},
+        {?__(72,"Chart to X"), align_x,
+        ?__(73,"Rotate chart to align (imaginary) edge joining selected verts to X-axis")},
+        {?__(74,"Chart to Y"), align_y,
+        ?__(75,"Rotate chart to align (imaginary) edge joining selected verts to Y-axis")}],
 
     Menu = [{?__(77,"Move"),{move,Move},?__(78,"Move selected vertices"),[magnet]},
 	    {?__(79,"Scale"),{scale,Scale},?__(80,"Scale selected vertices"), [magnet]},
@@ -484,6 +480,8 @@ command_menu(vertex, X, Y) ->
                                 [{"X", x, ?__(84,"Flatten horizontally")},
                                  {"Y", y, ?__(85,"Flatten vertically")}]},
 	     ?__(86,"Flatten selected vertices")},
+        align_menu(),
+        {?__(76,"Bend"),bend_submenu_items(),?__(93,"Plastic Bend")},
 	    {?__(87,"Tighten"),tighten,
 	     ?__(88,"Move UV coordinates towards average midpoint"),
 	     [magnet]},
@@ -529,6 +527,20 @@ scale_directions(false) ->
      {?__(3,"Horizontal"), x, ?__(4,"Scale horizontally (X dir)")},
      {?__(5,"Vertical"),   y, ?__(6,"Scale vertically (Y dir)")}].
 
+align_menu() ->
+    {?__(93,"Align"),
+     {align,
+      [{?__(15,"Bottom"), bottom, ?__(95,"Align to bottom")},
+       {?__(17,"Top"), top, ?__(96,"Align to top")},
+       {?__(19,"Left"), left, ?__(97,"Align to left")},
+       {?__(21,"Right"), right, ?__(98,"Align to right")}
+      ]}, ?__(94,"Align charts relative each other")}.
+
+bend_submenu_items() ->
+    {bend,{plastic_bend,noclamp},
+             {'ASK',{[{point, ?__(1,"Pick rod center")},
+                      {point, ?__(2,"Pick rod top")},
+                      {axis,  ?__(3,"Pick bend normal")}],[],[]}}}.
 
 max_uniform() ->
     fun
@@ -883,7 +895,7 @@ handle_command_1({scale,normalize}, St0) -> %% Normalize chart sizes
 				      end, {0.0,0.0,[]}, St0),
     TScale = TA2D/TA3D,
     Scale = fun({A2D,A3D,We0 = #we{id=WId}},Sh) ->
-		    Scale = math:sqrt(TScale * A3D/A2D),
+		    Scale = math:sqrt(TScale * A3D/wings_util:nonzero(A2D)),
 		    Center = wings_vertex:center(We0),
 		    T0 = e3d_mat:translate(e3d_vec:neg(Center)),
 		    SM = e3d_mat:scale(Scale, Scale, 1.0),
@@ -926,9 +938,9 @@ handle_command_1({move_to,Dir}, St0) ->
     St1 = wpa:sel_map(fun(_, We) -> move_to(Dir,We) end, St0),
     St = update_selected_uvcoords(St1),
     get_event(St);
-handle_command_1({align,Dir}, #st{selmode=Mode,sel=[{_,Els}]}=St0) ->
+handle_command_1({align,Dir}, #st{selmode=Mode,sel=Sel}=St0) when Mode == body; Mode == vertex ->
     St =
-        case gb_sets:size(Els) of
+        case length(Sel) of
             1 ->
                 align_error(Mode),
                 St0;
@@ -938,6 +950,12 @@ handle_command_1({align,Dir}, #st{selmode=Mode,sel=[{_,Els}]}=St0) ->
                 update_selected_uvcoords(St1)
         end,
     get_event(St);
+handle_command_1({bend,Type,{'ASK',Ask}}, St) ->
+    wings:ask(Ask, St, fun(B,St0) ->
+                    do_drag(wpc_bend:setup({Type,B}, St0))
+               end);
+handle_command_1({bend,{Type,Param}}, St) ->
+    wpc_bend:setup({Type,Param}, St);
 handle_command_1({flip,horizontal}, St0) ->
     St1 = wpa:sel_map(fun(_, We) -> flip_horizontal(We) end, St0),
     St = update_selected_uvcoords(St1),
@@ -1153,6 +1171,27 @@ mag_vertex_tighten(Vs0, We, Magnet) ->
     Vs = [V || V <- gb_sets:to_list(Vs0), not_bordering(V, Vis, We)],
     wings_vertex_cmd:tighten_vs(Vs, We, Magnet).
 
+equal_length(Op,#st{bb=Uvs}=St) when Op == proportional ->
+    #uvstate{st=#st{shapes=Shs0},id=Id} = Uvs,
+    #we{es=Etab} = We = gb_trees:get(Id, Shs0),
+    wings_sel:map(fun(Es, #we{name=#ch{emap=Emap}}=UvWe) ->
+                EuvToEwe = [{E,auv_segment:map_edge(E,Emap)} || E <- gb_sets:to_list(Es)],
+                UvLinks = wings_edge_loop:edge_links(Es,UvWe),
+                PickVs = fun(E) ->
+                            #edge{vs=Vs,ve=Ve} = array:get(E, Etab),
+                            {E,Vs,Ve}
+                         end,
+                WeVs = ordsets:from_list([PickVs(E) || {_,E} <- EuvToEwe]),
+                RemapVs = fun(E0) ->
+                        E = proplists:get_value(E0,EuvToEwe),
+                        {_,Ve,Vs} = lists:keyfind(E,1,WeVs),
+                        %% we use the edge id from island instead of the real object one
+                        {E0,Ve,Vs}
+                    end,
+                %% sync edge loops from the island with the edges on real object
+                WeLinks = [[RemapVs(E) || {E,_,_} <- UvLink] || UvLink <- UvLinks],
+                make_proportional(UvLinks,UvWe,WeLinks,We)
+          end, St);
 equal_length(Op,St) ->
     wings_sel:map(fun(Es, We) ->
 			  Links = wings_edge_loop:edge_links(Es,We),
@@ -1186,6 +1225,115 @@ make_equal(Op,[Link0|R],We = #we{vp=Vtab}) ->
     end;
 make_equal(_,[],We) -> We.
 
+make_proportional([[_]|R], We, [_|RObj], WeObj) ->
+    %% avoiding single edge selections
+    make_proportional(R,We,RObj,WeObj);
+make_proportional([Link0|R],We = #we{vp=Vtab1}, [LinkObj0|RObj], WeObj = #we{vp=VtabObj}) ->
+    case length(Link0) of
+        X when X < 2 -> make_proportional(R,We,RObj,WeObj);
+        _No ->
+            {Link,LinkObj} =
+                case Link0 of
+                   [{_,A,_},{_,_,A}|_] -> {Link0,LinkObj0};
+                   [{_,_,A},{_,A,_}|_] -> {reverse(Link0),reverse(LinkObj0)}
+                end,
+            %% get the edge loop and edges length from the real object
+            {LinkObjLen,EsObjLen} =
+                lists:foldl(fun({E,Ve,Vs}, {Len,Acc}) ->
+                                ELen = e3d_vec:dist(array:get(Ve,VtabObj),
+                                                    array:get(Vs,VtabObj)),
+                                {Len+ELen,[{E,ELen}|Acc]}
+                            end,{0.0,[]},LinkObj),
+            %% get the edge loop and edges length from the UV island
+            {LinkLen,EsLen0} =
+                lists:foldl(fun({_E,Ve,Vs}=E, {Len,Acc}) ->
+                                {Xd,Yd,_} = e3d_vec:sub(array:get(Ve,Vtab1),
+                                                        array:get(Vs,Vtab1)),
+                                ELen = e3d_vec:len({Xd,Yd,0.0}),
+                                Dir = if (ELen =:= 0.0) -> none;
+                                      true -> e3d_vec:norm({Xd,Yd,0.0})
+                                      end,
+                                {Len+ELen,[{E,Dir}|Acc]}
+                            end,{0.0,[]},Link),
+            EsLen = validate_dir(EsLen0,[]),
+            %% computing original loop information (BB, Length and rotation)
+            [{{_,Ve0,_},_}|_] = EsLen,
+            [{{_,_,Vs0},_}|_] = lists:reverse(EsLen),
+            IsLoop = Ve0=:=Vs0,
+            V0e = array:get(Ve0,Vtab1),
+            V0s = array:get(Vs0,Vtab1),
+            Es = [Ve || {{_,Ve,_},_} <- EsLen],
+            if not IsLoop ->
+                Mid0 = e3d_vec:average(V0e,V0s);
+            true ->
+                Mid0 = e3d_vec:average([array:get(V,Vtab1) || V <- Es])
+            end,
+            Vec0 = e3d_vec:sub(V0e,V0s),
+            D0 = e3d_vec:len(Vec0),
+            %% computing the new vertices location
+            Vtab0 =
+                lists:foldr(fun({{E,Ve,Vs},Dir0}, Acc) ->
+                                EObjLen = proplists:get_value(E,EsObjLen),
+                                if LinkObjLen =/= 0.0 -> Prc = EObjLen/LinkObjLen;
+                                true -> Prc = 1.0
+                                end,
+                                ELen = Prc*LinkLen,
+                                Dir = e3d_vec:mul(Dir0,ELen),
+                                Pos = e3d_vec:add(array:get(Vs,Acc),Dir),
+                                array:set(Ve,Pos,Acc)
+                            end,Vtab1,EsLen),
+            %% computing new loop information (BB, Length and rotation)
+            V1e = array:get(Ve0,Vtab0),
+            V1s = array:get(Vs0,Vtab0),
+            if not IsLoop ->
+                Mid1 = e3d_vec:average(V1e,V1s);
+            true ->
+                Mid1 = e3d_vec:average([array:get(V,Vtab0) || V <- Es])
+            end,
+            Vec1 = e3d_vec:sub(V1e,V1s),
+            D1 = e3d_vec:len(Vec1),
+
+            %% making the new loop arrangement fit in the old BB length and alignment
+            if D1 =/= 0.0 -> Scl = round((D0/D1)*100.0)/100.0;
+            true -> Scl = 1.0
+            end,
+            {_,_,RotSide} = e3d_vec:norm(e3d_vec:cross(Vec1,Vec0)),
+            Rot = round(e3d_vec:degrees(Vec1,Vec0)*10.0)/10.0*RotSide,
+            MToOri = e3d_mat:translate(e3d_vec:neg(Mid1)),
+            if (Rot=/=0.0) or (Scl=/=1.0) ->
+                %% preparing transform matrices
+                MRot = e3d_mat:rotate(Rot,wings_util:make_vector(z)),
+                MScl = e3d_mat:scale({Scl,Scl,1.0}),
+                MToDst = e3d_mat:translate(Mid0),
+                M2 = e3d_mat:mul(MScl,MToOri),
+                M1 = e3d_mat:mul(MRot,M2),
+                M0 = e3d_mat:mul(MToDst,M1);
+            true ->
+                MToDst = e3d_mat:translate(Mid0),
+                M0 = e3d_mat:mul(MToDst,MToOri)
+            end,
+
+            Vtab =
+                lists:foldr(fun(V, Acc) ->
+                                Pos = e3d_mat:mul_point(M0,array:get(V,Acc)),
+                                array:set(V,Pos,Acc)
+                            end,Vtab0,Es),
+            make_proportional(R,We#we{vp=Vtab},RObj,WeObj)
+    end;
+make_proportional([],We,_,_) -> We.
+
+%% ensuring the 0 length segments are going to have a valid direction
+validate_dir([{_,none}], [{_,none}|Acc]) -> lists:reverse(Acc);
+validate_dir([{E,none}], [{_,Dir}|_]=Acc) ->
+    validate_dir([{E,Dir}],Acc);
+validate_dir([E0], Acc) -> lists:reverse([E0|Acc]);
+validate_dir([{E,none}|[{_,Dir}|_]=Es], Acc) when Dir =/= none ->
+    validate_dir(Es, [{E,Dir}|Acc]);
+validate_dir([{_,Dir}=E0,{E,none}], Acc) when Dir =/= none ->
+    validate_dir([{E,Dir}], [E0|Acc]);
+validate_dir([E0|Es], Acc) ->
+    validate_dir(Es, [E0|Acc]).
+
 calc_areas(We,OWe,{TA2D,TA3D,L}) ->
     Fs = wings_we:visible(We),
     {A2D,A3D} = 
@@ -1390,7 +1538,7 @@ displace_edges([{_,{Id,Edge1,{Vs1,Ve1}},{Id,_,{Vs2,Ve2}}}|Eds], Sh) ->
 	    displace_edges(Eds,Sh);
 	_ ->
 	    %% What Direction should we displace the verts?
-	    [Move1,Move2] = displace_dirs(0.0000001,Edge1,We),
+	    [Move1,Move2] = displace_dirs(?EPSILON,Edge1,We),
 	    %% Make the move
 	    Vpos = foldl(fun({V1,V2},VpIn) ->
 				 Pos1 = e3d_vec:add(Move1,array:get(V1,Vpos0)),
@@ -1414,9 +1562,9 @@ displace_charts([{_,{Id1,_,_},{Id2,_,_}}|Eds], Moved, Sh) ->
 	    We0 = #we{vp=Vpos0} = gb_trees:get(Id1,Sh),
 	    C1 = wings_vertex:center(We0),
 	    C2 = wings_vertex:center(gb_trees:get(Id2,Sh)),
-	    Disp0 = e3d_vec:mul(e3d_vec:norm(e3d_vec:sub(C1,C2)),0.0000001),
+	    Disp0 = e3d_vec:mul(e3d_vec:norm(e3d_vec:sub(C1,C2)),?EPSILON),
 	    Move = case Disp0 of
-		       {0.0,0.0,0.0} -> {0.0,0.0000001,0.0};
+		       {0.0,0.0,0.0} -> {0.0,?EPSILON,0.0};
 		       Disp -> Disp
 		   end,
 	    Vpos= [{V,e3d_vec:add(Pos,Move)} || 
@@ -1778,8 +1926,10 @@ align_chart(Dir, V1={X1,Y1,_},V2={X2,Y2,_}, We) ->
     rotate_chart(-Deg,Center,We).
 
 -spec align_error(term()) -> no_return().
-align_error(Mode) when Mode==edge; Mode==vertex ->
-    wings_u:error_msg(?__(1,"Select two vertices or one edge"));
+align_error(vertex) ->
+    wings_u:error_msg(?__(1,"Select at least two vertices. One in each chart that must be aligned"));
+align_error(edge) ->
+    wings_u:error_msg(?__(3,"Select only one edge in each chart that must be aligned"));
 align_error(body) ->
     wings_u:error_msg(?__(2,"Select at least two charts to be aligned to each other")).
 
@@ -1829,7 +1979,7 @@ stretch(Dir,We) ->
     [{X1,Y1,_},{X2,Y2,_}] = wings_vertex:bounding_box(We),
     Center = {CX,CY,CZ} = {X1+(X2-X1)/2, Y1+(Y2-Y1)/2, 0.0},
     T0 = e3d_mat:translate(e3d_vec:neg(Center)),
-    SX0 = 1.0/(X2-X1), SY0= 1.0/(Y2-Y1),
+    SX0 = 1.0/wings_util:nonzero(X2-X1), SY0= 1.0/wings_util:nonzero(Y2-Y1),
     {SX,SY} = case Dir of
                 max_x -> {SX0, 1.0};
                 max_y -> {1.0, SY0};
@@ -2111,4 +2261,3 @@ geom2auv_edges(Es, #we{name=#ch{emap=Emap0}}) ->
 		      {value,Hits} -> Hits ++ Acc
 		  end
 	  end, [], Es).
-    
