@@ -144,7 +144,7 @@ menu_string1(Mode,Type) ->
           Str = ?__(3,"Calculate the angle between any two ~s and save the result as a rotation constraint in the Preferences"),
           wings_util:format(Str,[PMdeStr]);
       {Mode,sub_angle} ->
-          ?__(4,"Calculate the differnce between two angles and save the result as a rotation constraint in the Preferences");
+          ?__(4,"Calculate the difference between two angles and save the result as a rotation constraint in the Preferences");
       {Mode,to_axis} ->
           Str = ?__(5,"Measure the angle between a single ~s and a standard axis or defined vector. Save the result as a rotation constraint in the Preferences"),
           wings_util:format(Str,[SMdeStr]);
@@ -202,13 +202,13 @@ menu_string3(advanced,Mode,Type,Axis1,Axis2) ->
 
       {Mode,average,none,normal} ->
           ?__(1,"Measure the selected edges along their normals")++
-          ?__(22," and then caluculate their average length");
+          ?__(22," and then calculate their average length");
       {Mode,average,none,'ASK'} ->
           ?__(2,"Pick an axis along which to measure the selected edges")++
-          ?__(22," and then caluculate their average length");
+          ?__(22," and then calculate their average length");
       {Mode,average,none,Axis2} ->
           Str = ?__(3,"Measure the selected edges only along the ~s axis"),
-          wings_util:format(Str,[Axs2Str])++?__(22," and then caluculate their average length");
+          wings_util:format(Str,[Axs2Str])++?__(22," and then calculate their average length");
 
       {Mode,angle,none,normal} ->
           ?__(4,"Measure the selected angle");
