@@ -412,7 +412,7 @@ intersects({1.0,0.0,0.0}=Plane, {X,_,_}=CutPoint, #we{es=Etab,vp=Vtab}) ->
       (Edge, #edge{vs=Va,ve=Vb}, EdgesToCut1) ->
         {Xa,_,_} = PosA = array:get(Va, Vtab),
         {Xb,_,_} = PosB = array:get(Vb, Vtab),
-        case oposite_sides(Xa, Xb, X) of
+        case opposite_sides(Xa, Xb, X) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -429,7 +429,7 @@ intersects({0.0,1.0,0.0}=Plane, {_,Y,_}=CutPoint, #we{es=Etab,vp=Vtab}) ->
       (Edge, #edge{vs=Va,ve=Vb}, EdgesToCut1) ->
         {_,Ya,_} = PosA = array:get(Va, Vtab),
         {_,Yb,_} = PosB = array:get(Vb, Vtab),
-        case oposite_sides(Ya, Yb, Y) of
+        case opposite_sides(Ya, Yb, Y) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -446,7 +446,7 @@ intersects({0.0,0.0,1.0}=Plane, {_,_,Z}=CutPoint, #we{es=Etab,vp=Vtab}) ->
       (Edge, #edge{vs=Va,ve=Vb}, EdgesToCut1) ->
         {_,_,Za} = PosA = array:get(Va, Vtab),
         {_,_,Zb} = PosB = array:get(Vb, Vtab),
-        case oposite_sides(Za, Zb, Z) of
+        case opposite_sides(Za, Zb, Z) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -464,7 +464,7 @@ intersects(Plane, CutPoint, #we{es=Etab,vp=Vtab}) ->
       (Edge, #edge{vs=Va,ve=Vb}, EdgesToCut1) ->
         {SideA,PosA} = array:get(Va, SideArray),
         {SideB,PosB} = array:get(Vb, SideArray),
-        case oposite_sides(SideA, SideB) of
+        case opposite_sides(SideA, SideB) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -487,7 +487,7 @@ intersects(Faces, {1.0,0.0,0.0}=Plane, {X,_,_}=CutPoint, #we{es=Etab,vp=Vtab}=We
         #edge{vs=Va,ve=Vb} = array:get(Edge, Etab),
         {Xa,_,_} = PosA = array:get(Va, Vtab),
         {Xb,_,_} = PosB = array:get(Vb, Vtab),
-        case oposite_sides(Xa, Xb, X) of
+        case opposite_sides(Xa, Xb, X) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -506,7 +506,7 @@ intersects(Faces, {0.0,1.0,0.0}=Plane, {_,Y,_}=CutPoint, #we{es=Etab,vp=Vtab}=We
         #edge{vs=Va,ve=Vb} = array:get(Edge, Etab),
         {_,Ya,_} = PosA = array:get(Va, Vtab),
         {_,Yb,_} = PosB = array:get(Vb, Vtab),
-        case oposite_sides(Ya, Yb, Y) of
+        case opposite_sides(Ya, Yb, Y) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -525,7 +525,7 @@ intersects(Faces, {0.0,0.0,1.0}=Plane, {_,_,Z}=CutPoint, #we{es=Etab,vp=Vtab}=We
         #edge{vs=Va,ve=Vb} = array:get(Edge, Etab),
         {_,_,Za} = PosA = array:get(Va, Vtab),
         {_,_,Zb} = PosB = array:get(Vb, Vtab),
-        case oposite_sides(Za, Zb, Z) of
+        case opposite_sides(Za, Zb, Z) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -544,7 +544,7 @@ intersects(Faces, Plane, CutPoint, #we{es=Etab,vp=Vtab}=We0) ->
         #edge{vs=Va,ve=Vb} = array:get(Edge, Etab),
         PosA = array:get(Va, Vtab),
         PosB = array:get(Vb, Vtab),
-        case oposite_sides(PosA, PosB, CutPoint, Plane) of
+        case opposite_sides(PosA, PosB, CutPoint, Plane) of
           true ->
             EdgeVec = e3d_vec:norm_sub(PosA, PosB),
              case abs(e3d_vec:dot(Plane, EdgeVec)) < ?NON_ZERO of
@@ -660,18 +660,18 @@ intersect_vec_plane(PosA, PosB, Plane, EdgeVec) ->
 %% Tests whether the 2 vertices of an edge are on opposite sides of the Plane.
 %% The opposite_sides function that is used depends on the Plane and the
 %% selection mode.
-oposite_sides(A, B) when A =:= on_vertex; B =:= on_vertex -> true;
-oposite_sides(Side, Side) -> false;
-oposite_sides(_, _) -> true.
+opposite_sides(A, B) when A =:= on_vertex; B =:= on_vertex -> true;
+opposite_sides(Side, Side) -> false;
+opposite_sides(_, _) -> true.
 
-oposite_sides(_, B, B) -> true;
-oposite_sides(A, _, A) -> true;
-oposite_sides(A, B, C) ->
+opposite_sides(_, B, B) -> true;
+opposite_sides(A, _, A) -> true;
+opposite_sides(A, B, C) ->
     SideA = A < C,
     SideB = B < C,
     SideA =/= SideB.
 
-oposite_sides(PosA, PosB, CutPoint, Plane) ->
+opposite_sides(PosA, PosB, CutPoint, Plane) ->
     VecA = e3d_vec:norm_sub(PosA, CutPoint),
     VecB = e3d_vec:norm_sub(PosB, CutPoint),
     Zero = e3d_vec:zero(),
