@@ -59,15 +59,17 @@ do_export(Ask, Op, _Exporter, _St) when is_atom(Ask) ->
 	       fun(Res) ->
 		       {file,{Op,{glb,Res}}}
 	       end);
-do_export(Attr, _Op, Exporter, _St) when is_list(Attr) ->
+do_export(Attr, _Op, Exporter, #st{file=File}=_St) when is_list(Attr) ->
     set_pref(Attr),
     SubDivs = proplists:get_value(subdivisions, Attr, 0),
     Uvs = proplists:get_bool(include_uvs, Attr),
+    FileName = filename:basename(File,".wings"),
     %% Units = proplists:get_value(units, Attr),
     Ps = [{include_uvs,Uvs},%% {units,Units},
           {tesselation, triangulate},
           {include_hard_edges, true},
-	  {subdivisions,SubDivs}|props()],
+          {subdivisions,SubDivs},
+          {default_filename,FileName}|props(proplists:get_value(file_type, Attr))],
     Exporter(Ps, export_fun(Attr)),
     keep.
 
@@ -83,10 +85,12 @@ dialog(Type) ->
      %% wpa:dialog_template(?MODULE, units), panel,
      wpa:dialog_template(?MODULE, Type, [include_colors, include_normals])].
 
-props() ->
-    [{extensions,
-      [{".glb",  "gltf binary"},
-       {".gltf", "gl Transmission Format"}]}].
+props(Type) ->
+    Ext = case Type of
+              glb -> {".glb",  "gltf binary"};
+              gltf -> {".gltf", "gl Transmission Format"}
+          end,
+    [{extensions, [Ext]}].
 
 set_pref(KeyVals) ->
     wpa:pref_set(?MODULE, KeyVals).
