@@ -220,8 +220,7 @@ setup_dialog(Parent, Entries, Magnet, ScreenPos, Cache) ->
             end,
             MenuData;
         #{frame := Frame} = MenuData ->
-            Pos = fit_menu_on_display(Frame,ScreenPos),
-            wxWindow:move(Frame, Pos),
+            wxWindow:move(Frame, ScreenPos),
             wxPopupTransientWindow:popup(Frame),
             MenuData
     end.
@@ -246,7 +245,7 @@ do_setup_dialog(TopParent, Entries0, Magnet, ScreenPos) ->
     wxPanel:setSizer(Panel, Main),
     wxSizer:fit(Main, Panel),
     wxWindow:setClientSize(Frame, wxWindow:getSize(Panel)),
-    wxWindow:move(Frame, fit_menu_on_display(Frame, ScreenPos)),
+    wxWindow:move(Frame, ScreenPos),
     show_menu_frame(Overlay, Frame, KbdFocus),
     #{overlay=>Overlay, frame=>Frame, panel=>Panel, entries=>Entries, colors=>Cols}.
 
@@ -391,41 +390,19 @@ popup_events(MenuData, Magnet, Previous, Ns, Owner) ->
 		    wings_wm:psend(Owner, {click, Id, {mouse_button(Ev), MagnetClick}, Ns})
 	    end;
         cancel ->
-            {BG,FG} = maps:get(colors, MenuData),
-            setup_colors(Previous, BG, FG),
             wings_wm:psend(Owner, cancel);
-        {move, {X,Y}} ->
+        {move, Pos} ->
             Frame = maps:get(frame, MenuData),
-            Pos = fit_menu_on_display(Frame, {X,Y}),
             wxWindow:move(Frame, Pos),
             wings_wm:psend(Owner, redraw),
             popup_events(MenuData, Magnet, Previous, Ns, Owner);
         #wx{event=#wxShow{show=false}} ->
-            {BG,FG} = maps:get(colors, MenuData),
-            setup_colors(Previous, BG, FG),
             wings_wm:psend(Owner, cancel);
 	_Ev ->
 	    %% ?dbg("Got Ev ~p ~n", [_Ev]),
 	    popup_events(MenuData, Magnet, Previous, Ns, Owner)
     end.
 
-fit_menu_on_display(Frame, {MX,MY} = Pos) ->
-    {WW,WH} = wxWindow:getSize(Frame),
-    DisplayID = wxDisplay:getFromPoint(Pos),
-    Display = wxDisplay_new(DisplayID),
-    {DX,DY,DW,DH} = wxDisplay:getClientArea(Display),
-    MaxW = (DX+DW),
-    PX = if (MX+WW) > MaxW -> MaxW-WW-2;
-            (MX-25) < DX -> MX;
-            true -> max(5, (MX-25)) %% Move so mouse is inside menu
-         end,
-    MaxH = (DY+DH),
-    PY = if (MY+WH) > MaxH -> MaxH-WH-2;
-            true -> max(5, (MY-15)) %% Move so mouse is inside menu
-         end,
-    wxDisplay:destroy(Display),
-    {PX,PY}.
-
 %% If the mouse is not moved after popping up the menu, the menu entry
 %% is not active, find_active_panel finds the active row.
 find_active_panel(Panel, MX, MY) ->
@@ -493,8 +470,7 @@ popup_event_handler({click, Id, Click, Ns}, {Parent,Owner}, Entries0) ->
             wings_wm:release_focus(),
             delete;
 	{submenu, Names, Menus, MagnetClick} ->
-	    {_, X,Y} = wings_io:get_mouse_state(),
-	    Entries = wx_popup_menu(Parent, {X,Y}, Names, Menus, MagnetClick, dialog_blanket),
+	    Entries = wx_popup_menu(Parent, wx_misc:getMousePosition(), Names, Menus, MagnetClick, dialog_blanket),
 	    {replace, fun(Ev) -> popup_event_handler(Ev, {Parent,Owner}, Entries) end}
     end;
 popup_event_handler(redraw,_,_) ->
@@ -733,20 +709,20 @@ tooltip(HelpL, "", "", Magnet, _) ->
     {str_clean(HelpL) ++ magnet_help(tip, Magnet),
      wings_msg:join(HelpL,magnet_help(str, Magnet))};
 tooltip(HelpL, HelpM, "", Magnet, HK) ->
-    {io_lib:format(?__(1, "Left mouse button") ++ ": ~ts" ++ tooltip_hk(1,HK) ++ "~n" ++
-		       ?__(2, "Middle mouse button") ++ ": ~ts" ++ tooltip_hk(2,HK),
-		   [HelpL, HelpM]) ++ magnet_help(tip, Magnet),
+    {io_lib:format(?__(1, "Left mouse button") ++ ": ~ts~ts~n" ++
+		       ?__(2, "Middle mouse button") ++ ": ~ts~ts",
+		   [HelpL, tooltip_hk(1,HK), HelpM, tooltip_hk(2,HK)]) ++ magnet_help(tip, Magnet),
      wings_msg:join(wings_msg:button_format(HelpL, HelpM, ""),magnet_help(str, Magnet))};
 tooltip(HelpL, "", HelpR, Magnet, HK) ->
-    {io_lib:format(?__(1, "Left mouse button") ++ ": ~ts" ++ tooltip_hk(1,HK) ++ "~n" ++
-		       ?__(3, "Right mouse button") ++ ": ~ts" ++ tooltip_hk(3,HK),
-		   [HelpL, HelpR]) ++ magnet_help(tip, Magnet),
+    {io_lib:format(?__(1, "Left mouse button") ++ ": ~ts~ts~n" ++
+		       ?__(3, "Right mouse button") ++ ": ~ts~ts",
+		   [HelpL, tooltip_hk(1,HK), HelpR, tooltip_hk(3,HK)]) ++ magnet_help(tip, Magnet),
      wings_msg:join(wings_msg:button_format(HelpL, "", HelpR), magnet_help(str, Magnet))};
 tooltip(HelpL, HelpM, HelpR, Magnet, HK) ->
-    {io_lib:format(?__(1, "Left mouse button") ++ ": ~ts" ++ tooltip_hk(1,HK) ++ "~n" ++
-		       ?__(2, "Middle mouse button") ++ ": ~ts" ++ tooltip_hk(2,HK) ++ "~n" ++
-		       ?__(3, "Right mouse button") ++ ": ~ts" ++ tooltip_hk(3,HK),
-		   [HelpL, HelpM, HelpR]) ++ magnet_help(tip, Magnet),
+    {io_lib:format(?__(1, "Left mouse button") ++ ": ~ts~ts~n" ++
+		       ?__(2, "Middle mouse button") ++ ": ~ts~ts~n" ++
+		       ?__(3, "Right mouse button") ++ ": ~ts~ts",
+		   [HelpL, tooltip_hk(1,HK), HelpM, tooltip_hk(2,HK), HelpR, tooltip_hk(3,HK)]) ++ magnet_help(tip, Magnet),
      wings_msg:join(wings_msg:button_format(HelpL, HelpM, HelpR), magnet_help(str, Magnet))}.
 
 tooltip_hk(Mb, HK) ->
