@@ -25,6 +25,10 @@
 -import(lists, [foldl/3]).
 
 init() ->
+    gl:clear(?GL_COLOR_BUFFER_BIT bor ?GL_DEPTH_BUFFER_BIT),
+    gl:pixelStorei(?GL_UNPACK_ALIGNMENT, 1),
+    {R,G,B} = wings_pref:get_value(background_color),
+    gl:clearColor(R, G, B, 1.0),
     wings_pref:set_default(multisample, true),
     wings_pref:set_default(smooth_alpha, 0.850013),
     init_polygon_stipple().
@@ -48,13 +52,13 @@ render(#st{selmode=Mode}=St) ->
     end,
     {PM,MM,SceneLights} = wings_view:load_matrices(true),
     View = wings_view:current(),
+    draw_background(MM),
     mini_axis_icon(View, MM),
     show_saved_bb(St),
     show_bb_center(St),
     user_clipping_planes(on),
     RS = render_objects(Mode, PM, MM, SceneLights),
     user_clipping_planes(off),
-    draw_background(MM),
     call_post_hook(St),
     ground_and_axes(View, PM,MM, RS),
     show_camera_image_plane(),
